@@ -17,25 +17,33 @@ class PrometheusFastApiInstrumentator:
         should_ignore_untemplated: bool = False,
         should_group_untemplated: bool = True,
         should_round_latency_decimals: bool = False,
+        should_respect_env_var: bool = False,
         excluded_handlers: list = ["/metrics"],
         buckets: tuple = Histogram.DEFAULT_BUCKETS,
         metric_name: str = "http_request_duration_seconds",
         label_names: tuple = ("method", "handler", "status",),
         round_latency_decimals: int = 4,
+        env_var_name: str = "ENABLE_METRICS",
     ):
         """
         :param should_group_status_codes: Should status codes be grouped into 
-            2xx, 3xx and so on?
+            `2xx`, `3xx` and so on?
 
         :param should_ignore_untemplated: Should requests without a matching 
             template be ignored?
 
         :param should_group_untemplated: Should requests without a matching 
-            template be grouped to handler None?
+            template be grouped to handler `none`?
 
         :param should_round_latency_decimals: Should recorded latencies be 
             rounded to a certain number of decimals?
 
+        :param should_respect_env_var: Should the instrumentator only 
+            work - for example the methods `instrument()` and `expose()` - if 
+            a certain environment variable is set to `true`? Usecase: A base 
+            FastAPI app that is used by multiple distinct apps. The apps only 
+            have to set the variable to be instrumented.
+
         :param excluded_handlers: Handlers that should be ignored. List of 
             strings is turned into regex patterns.
 
@@ -48,16 +56,22 @@ class PrometheusFastApiInstrumentator:
             "status",).
 
         :param round_latency_decimals: Number of decimals latencies should be 
-            rounded to, provided `should_round_latency_decimals` is `True`.
+            rounded to. Ignored unless `should_round_latency_decimals` is `True`.
+
+        :param env_var_name: Any valid os environment variable name that 
+            will be checked for existence before instrumentation. Ignored 
+            unless `should_respect_env_var_existence` is `True`.
         """
 
         self.should_group_status_codes = should_group_status_codes
         self.should_ignore_untemplated = should_ignore_untemplated
         self.should_group_untemplated = should_group_untemplated
         self.should_round_latency_decimals = should_round_latency_decimals
+        self.should_respect_env_var = should_respect_env_var
 
         self.round_latency_decimals = round_latency_decimals
         self.label_names = label_names
+        self.env_var_name = env_var_name
 
         if excluded_handlers:
             self.excluded_handlers = [re.compile(path) for path in excluded_handlers]
@@ -83,6 +97,12 @@ class PrometheusFastApiInstrumentator:
         :param return: self.
         """
 
+        if (
+            self.should_respect_env_var
+            and os.environ.get(self.env_var_name, "false") != "true"
+        ):
+            return self
+
         @app.middleware("http")
         async def dispatch_middleware(request: Request, call_next) -> Response:
             start_time = default_timer()
@@ -120,7 +140,9 @@ class PrometheusFastApiInstrumentator:
 
         return self
 
-    def expose(self, app: FastAPI, endpoint: str = "/metrics") -> "self":
+    def expose(
+        self, app: FastAPI, endpoint: str = "/metrics", include_in_schema: bool = True
+    ) -> "self":
         """Exposes Prometheus metrics by adding endpoint to the given app.
 
         **Important**: There are many different ways to expose metrics. This is 
@@ -129,9 +151,16 @@ class PrometheusFastApiInstrumentator:
 
         :param app: FastAPI where the endpoint should be added to.
         :param endpoint: Route of the endpoint. Defaults to "/metrics".
+        :param include_in_schema: Should the endpoint be included in schema?
         :param return: self.
         """
 
+        if (
+            self.should_respect_env_var
+            and os.environ.get(self.env_var_name, "false") != "true"
+        ):
+            return self
+
         from prometheus_client import (CONTENT_TYPE_LATEST, REGISTRY,
                                        CollectorRegistry, generate_latest,
                                        multiprocess)
@@ -148,7 +177,7 @@ class PrometheusFastApiInstrumentator:
         else:
             registry = REGISTRY
 
-        @app.get("/metrics")
+        @app.get("/metrics", include_in_schema=include_in_schema)
         def metrics():
             return Response(generate_latest(registry), media_type=CONTENT_TYPE_LATEST)
 
